<?php
/**
 * Functions to register client-side assets (scripts and stylesheets) for the
 * Gutenberg block.
 *
 * @package wp-webhotelier
 */

/**
 * Registers all block assets so that they can be enqueued through Gutenberg in
 * the corresponding context.
 *
 * @see https://wordpress.org/gutenberg/handbook/blocks/writing-your-first-block-type/#enqueuing-block-scripts
 */
function wp_webhotelier_block_init()
{
    // Skip block registration if Gutenberg is not enabled/merged.
    if (!function_exists('register_block_type')) {
        return;
    }

    $titan = TitanFramework::getInstance('wp-webhotelier');

    $prefix_options = 'wp-webhotelier-';

    $dir = dirname(__FILE__);

    $index_js = 'assets/index.js';
    wp_register_script(
        'wp-webhotelier-block-editor',
        plugins_url($index_js, __FILE__),
        array(
            'wp-blocks',
            'wp-i18n',
            'wp-element',
            'wp-components',
            'wp-editor',
        ),
        filemtime("$dir/$index_js")
    );

    $editor_css = 'assets/editor.css';
    wp_register_style(
        'wp-webhotelier-block-editor',
        plugins_url($editor_css, __FILE__),
        array(),
        filemtime("$dir/$editor_css")
    );

    $style_css = 'assets/style.css';
    wp_register_style(
        'wp-webhotelier-block',
        plugins_url($style_css, __FILE__),
        array(),
        filemtime("$dir/$style_css")
    );
    register_block_type('wp-webhotelier/block', array(
        'attributes'      => array(
            'url'           => array('type' => 'string', 'default' => $titan->getOption($prefix_options . 'url')),
            'max-nights'    => array('type' => 'number', 'default' => $titan->getOption($prefix_options . 'max-nights')),
            'max-rooms'     => array('type' => 'number', 'default' => $titan->getOption($prefix_options . 'max-rooms')),
            'max-adults'    => array('type' => 'number', 'default' => $titan->getOption($prefix_options . 'max-adults')),
            'max-children'  => array('type' => 'number', 'default' => $titan->getOption($prefix_options . 'max-children')),
            'max-infants'   => array('type' => 'number', 'default' => $titan->getOption($prefix_options . 'max-infants')),
            'orientation'   => array('type' => 'string', 'default' => $titan->getOption($prefix_options . 'orientation')),
            'checkout-date' => array('type' => 'string', 'default' => ($titan->getOption($prefix_options . 'checkout-date')) ? "1" : "0"),
            'css-class'     => array('type' => 'string', 'default' => $titan->getOption($prefix_options . 'css-class')),
        ),
        'editor_script'   => 'wp-webhotelier-block-editor',
        'editor_style'    => 'wp-webhotelier-block-editor',
        'style'           => 'wp-webhotelier-block',
        'render_callback' => 'wp_webhotelier_render_shortcode_block',
    ));
}
add_action('init', 'wp_webhotelier_block_init');

/**
 * It renders the shortcode for Gutenberg
 *
 * @param array $atts
 * @return string
 */
function wp_webhotelier_render_shortcode_block($atts)
{
    $shortcode_atts = '';

    foreach ($atts as $att_key => $att_value) {
        $shortcode_atts .= $att_key . '="' . $att_value . '" ';
    }

    return do_shortcode('[wp-webhotelier ' . trim($shortcode_atts) . ']');
}
