<?php
/**
 * The shortcodes functionality of the plugin.
 *
 * Defines the plugin name, version, and the shortcode.
 *
 * @package    Wp_Webhotelier
 * @subpackage Wp_Webhotelier/shortcode
 * @author     WPlugged <support@wplugged.com>
 */
class Wp_Webhotelier_Shortcode
{
    /**
     * The ID of this plugin.
     *
     * @var      string    $plugin_name    The ID of this plugin.
     */
    private $plugin_name;

    /**
     * Counter of how many times the shortcode has been shown
     *
     * @var integer
     */
    public static $shortcode_class_id = 0;

    /**
     * The ID html attribute for each shortcode rendered
     *
     * @var string
     */
    private $my_shortcode_id_num;

    public function __construct($plugin_name, $plugin_version)
    {
        $this->plugin_name    = $plugin_name;
        $this->plugin_version = $plugin_version;
        add_shortcode('wp-webhotelier', [$this, 'form_creation']);
    }

    /**
     * Returns the unique id for each instance of this class.
     * Mostly used to identify unique form elements.
     *
     * @return string
     */
    public function getId()
    {
        return "s-" . $this->my_shortcode_id_num;
    }

    /**
     * Outputs the HTML of the shortcode
     *
     * @return void
     */
    public function form_creation($atts = [], $content = null, $tag = 'wp-webhotelier')
    {

        $titan = TitanFramework::getInstance('wp-webhotelier');

        $prefix_options = 'wp-webhotelier-';

        // normalize attribute keys, lowercase
        $atts = array_change_key_case((array) $atts, CASE_LOWER);

        $default_client_options = [
            'url',
            'max-nights',
            'max-rooms',
            'max-adults',
            'max-children',
            'max-infants',
            'orientation',
            'checkout-date',
            'css-class',
        ];

        $default_shortcode_atts = [];
        foreach ($default_client_options as $value) {
            $default_shortcode_atts[$value] = $titan->getOption($prefix_options . $value);
        }

        // override default attributes with user attributes
        $wp_webhotelier_atts = shortcode_atts($default_shortcode_atts, $atts, $tag);

        //setting the id of the current view (and my_id for the page) of the loaded shortcode
        $this->my_shortcode_id_num = ++self::$shortcode_class_id;
        $my_id                     = $this->getId();

        ob_start();
        include plugin_dir_path(__FILE__) . '../public/partials/wp-webhotelier-form.php';
        return ob_get_clean();
    }
}
