<?php
/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Wp_Webhotelier
 * @subpackage Wp_Webhotelier/public
 * @author     WPlugged <support@wplugged.com>
 */
class Wp_Webhotelier_Public
{

    /**
     * The ID of this plugin.
     *
     * @var string    $plugin_name    The ID of this plugin.
     */
    private $plugin_name;

    /**
     * The version of this plugin.
     *
     * @var string    $version    The current version of this plugin.
     */
    private $version;

    /**
     * Initialize the class and set its properties.
     *
     * @param string    $plugin_name       The name of the plugin.
     * @param string    $version    The version of this plugin.
     */
    public function __construct($plugin_name, $version)
    {
        $this->plugin_name = $plugin_name;
        $this->version     = $version;
    }

    /**
     * Register the stylesheets for the public-facing side of the site.
     */
    public function enqueue_styles()
    {
        wp_enqueue_style($this->plugin_name . '-flatpickr', plugin_dir_url(__FILE__) . 'css/flatpickr.min.css', [], $this->version, 'all');
        wp_enqueue_style($this->plugin_name, plugin_dir_url(__FILE__) . 'css/wp-webhotelier-public.css', [], $this->version, 'all');
    }

    /**
     * Register the JavaScript for the public-facing side of the site.
     */
    public function enqueue_scripts()
    {
        wp_enqueue_script($this->plugin_name . '-flatpickr', plugin_dir_url(__FILE__) . 'js/flatpickr.js', ['jquery'], $this->version, true);
        wp_enqueue_script($this->plugin_name . '-public', plugin_dir_url(__FILE__) . 'js/wp-webhotelier-public.js', ['jquery', $this->plugin_name . '-flatpickr'], $this->version, true);
    }

}
